*Black* exceptions
==================

*Contents are subject to change.*

.. currentmodule:: black

.. autoexception:: black.trans.CannotTransform

.. autoexception:: black.linegen.CannotSplit

.. autoexception:: black.brackets.BracketMatchError

.. autoexception:: black.report.NothingChanged

.. autoexception:: black.parsing.InvalidInput

.. autoexception:: black.mode.Deprecated
